import { b as __rest, c as __assign, _ as __awaiter, a as __generator, n as normalizeComponent } from '../_chunks/normalize-component.2d07400a.js';
import mixins from 'vue-typed-mixins';
import mapboxgl from 'mapbox-gl';
import '../mixins/injectMap.ts';
import { unbindEvents, bindEvents } from '../utils/bind-events.ts';
import { b as bindProps } from '../_chunks/bind-props.6c703bd0.js';
import 'my-deferred';
import provideMap from '../mixins/provideMap.ts';
import './MapboxPopup.ts';
import __vue_component__$1 from './MapboxMarker.ts';

if (!mapboxgl) {
  throw new Error('mapboxgl is not installed.');
}
/**
   * Component's props definition, we need to declare it outside the component
   * to be able to test the default values and the types.
   * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map
   * @type {Object}
   */

/**
   * All Map events which will be mapped/bounded to the component
   * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map.event:resize
   * @type {Array}
   */


var events = ['resize', 'remove', 'mousedown', 'mouseup', 'mouseover', 'mousemove', 'click', 'dblclick', 'mouseenter', 'mouseleave', 'mouseout', 'contextmenu', 'wheel', 'touchstart', 'touchend', 'touchmove', 'touchcancel', 'movestart', 'move', 'moveend', 'dragstart', 'drag', 'dragend', 'zoomstart', 'zoom', 'zoomend', 'rotatestart', 'rotate', 'rotateend', 'pitchstart', 'pitch', 'pitchend', 'boxzoomstart', 'boxzoomend', 'boxzoomcancel', 'webglcontextlost', 'webglcontextrestored', 'load', 'render', 'idle', 'error', 'data', 'styledata', 'sourcedata', 'dataloading', 'styledataloading', 'sourcedataloading', 'styleimagemissing'];
var script = mixins(provideMap).extend({
  name: 'MapboxMap',
  components: {
    MapboxMarker: __vue_component__$1
  },
  props: {
    height: {
      type: String,
      default: '500px'
    },
    width: {
      type: String,
      default: '100%'
    },
    accessToken: {
      type: String,
      required: true
    },
    container: {
      type: [Object, String] || String,
      default: ''
    },
    minZoom: {
      type: Number,
      default: 0
    },
    maxZoom: {
      type: Number,
      default: 22
    },
    minPitch: {
      type: Number,
      default: 0
    },
    maxPitch: {
      type: Number,
      default: 60
    },
    mapStyle: {
      type: [Object, String],
      default: 'mapbox://styles/mapbox/streets-v11'
    },
    hash: {
      type: Boolean,
      default: false
    },
    interactive: {
      type: Boolean,
      default: true
    },
    bearingSnap: {
      type: Number,
      default: 7
    },
    pitchWithRotate: {
      type: Boolean,
      default: true
    },
    clickTolerance: {
      type: Number,
      default: 3
    },
    attributionControl: {
      type: Boolean,
      default: true
    },
    customAttribution: {
      type: Array,
      default: null
    },
    logoPosition: {
      type: String,
      default: 'bottom-left'
    },
    failIfMajorPerformanceCaveat: {
      type: Boolean,
      default: false
    },
    preserveDrawingBuffer: {
      type: Boolean,
      default: false
    },
    antialias: {
      type: Boolean,
      default: false
    },
    refreshExpiredTiles: {
      type: Boolean,
      default: true
    },
    maxBounds: {
      type: Array,
      default: undefined
    },
    scrollZoom: {
      type: [Boolean, Object],
      default: true
    },
    boxZoom: {
      type: Boolean,
      default: true
    },
    dragRotate: {
      type: Boolean,
      default: true
    },
    dragPan: {
      type: [Object, Boolean],
      default: true
    },
    keyboard: {
      type: Boolean,
      default: true
    },
    doubleClickZoom: {
      type: Boolean,
      default: true
    },
    touchZoomRotate: {
      type: [Boolean, Object],
      default: true
    },
    trackResize: {
      type: Boolean,
      default: true
    },
    center: {
      type: [Object, Array],
      default: function _default() {
        return [0, 0];
      }
    },
    zoom: {
      type: Number,
      default: 0
    },
    bearing: {
      type: Number,
      default: 0
    },
    pitch: {
      type: Number,
      default: 0
    },
    bounds: {
      type: Array,
      default: undefined
    },
    fitBoundsOptions: {
      type: Object,
      default: null
    },
    renderWorldCopies: {
      type: Boolean,
      default: true
    },
    maxTileCacheSize: {
      type: Number,
      default: null
    },
    localIdeographFontFamily: {
      type: String,
      default: 'sans-serif'
    },
    transformRequest: {
      type: Function,
      default: null
    },
    collectResourceTiming: {
      type: Boolean,
      default: false
    },
    fadeDuration: {
      type: Number,
      default: 300
    },
    crossSourceCollisions: {
      type: Boolean,
      default: true
    }
  },
  data: function data() {
    return {
      isLoaded: false,
      resizeObserver: null
    };
  },
  computed: {
    options: function options() {
      // eslint-disable-next-line no-unused-vars
      var _a = this.$props,
          _accessToken = _a._accessToken,
          style = _a.mapStyle,
          options = __rest(_a, ["_accessToken", "mapStyle"]); // Use current component's element if container is not set


      if (!options.container && this.$el) {
        options.container = this.$el;
      }

      return __assign({
        style: style
      }, options);
    },
    style: function style() {
      return {
        height: this.height,
        width: this.width
      };
    }
  },
  mounted: function mounted() {
    return __awaiter(this, void 0, void 0, function () {
      var map, observer;

      var _this = this;

      return __generator(this, function (_a) {
        mapboxgl.accessToken = this.accessToken;
        map = new mapboxgl.Map(this.options);
        map.on('load', function () {
          _this.$map.resolve(map);

          _this.isLoaded = true;
        }); // Bind props and events

        bindProps(this, map, this.$props);
        bindEvents(this, map, events);
        this.$emit('mb-created', map);
        observer = new ResizeObserver(this.resizeHandler);
        observer.observe(this.options.container);
        this.resizeObserver = observer;
        return [2
        /*return*/
        ];
      });
    });
  },
  destroyed: function destroyed() {
    unbindEvents(this, this.$map.val);
    if (this.resizeObserver) this.resizeObserver.disconnect();
    if (this.$map.val) this.$map.val.remove();
  },
  methods: {
    resizeHandler: function resizeHandler() {
      if (this.$map.val) {
        this.$map.val.resize();
      }
    }
  }
});

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    style: _vm.style
  }, [_vm.isLoaded ? _c('div', [_vm._t("default", null, {
    "default": {
      map: _vm.map
    }
  })], 2) : _c('div', [_vm._t("loader", [_c('div', {
    style: _vm.style
  })])], 2)]);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* module identifier */

var __vue_module_identifier__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

export default __vue_component__;
//# sourceMappingURL=MapboxMap.ts.map
